package secret

import (
	"path"
	"testing"

	"coopcloud.tech/abra/pkg/catalogue"
	"coopcloud.tech/abra/pkg/config"
	"coopcloud.tech/abra/pkg/recipe"
	"coopcloud.tech/abra/pkg/upstream/stack"
	loader "coopcloud.tech/abra/pkg/upstream/stack"
	"github.com/stretchr/testify/assert"
)

func TestReadSecretsConfig(t *testing.T) {
	if err := catalogue.EnsureCatalogue(); err != nil {
		t.Fatal(err)
	}

	offline := true
	recipe, err := recipe.Get("matrix-synapse", offline)
	if err != nil {
		t.Fatal(err)
	}

	sampleEnv, err := recipe.SampleEnv()
	if err != nil {
		t.Fatal(err)
	}

	composeFiles := []string{path.Join(config.RECIPES_DIR, recipe.Name, "compose.yml")}
	secretsFromConfig, err := ReadSecretsConfig(sampleEnv, composeFiles, recipe.Name)
	if err != nil {
		t.Fatal(err)
	}

	opts := stack.Deploy{Composefiles: composeFiles}
	config, err := loader.LoadComposefile(opts, sampleEnv)
	if err != nil {
		t.Fatal(err)
	}

	for secretId := range config.Secrets {
		assert.Contains(t, secretsFromConfig, secretId)
	}
}
